
Getting Started
===============

Install
-------

Please follow the instructions on the :doc:`install` page. For most users, the basic pip install is all that's needed.


Tutorials
---------

We have created a repository of tutorial Jupyter notebooks that can help initiate you on the main features of caustics. Please checkout the `tutorials here <https://github.com/Ciela-Institute/caustics-tutorials>`_ to see what caustics can do!


Read The Docs
-------------

Docs for all the main functions in caustics are available at :doc:`caustics` at varying degrees of completeness. Further development of the docs is always ongoing.
